import OCP.IntPolyh
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TColStd
import OCP.Bnd
import OCP.NCollection
import OCP.Adaptor3d
__all__  = [
"IntPolyh_Couple",
"IntPolyh_Edge",
"IntPolyh_Intersection",
"IntPolyh_ListOfCouples",
"IntPolyh_MaillageAffinage",
"IntPolyh_Point",
"IntPolyh_PointNormal",
"IntPolyh_SectionLine",
"IntPolyh_SeqOfStartPoints",
"IntPolyh_StartPoint",
"IntPolyh_Tools",
"IntPolyh_Triangle"
]
class IntPolyh_Couple():
    """
    The class represents the couple of indices with additional characteristics such as analyzed flag and an angle. In IntPolyh_MaillageAffinage algorithm the class is used as a couple of interfering triangles with the intersection angle.
    """
    def Angle(self) -> float: 
        """
        Returns the angle
        """
    def Dump(self,v : int) -> None: ...
    def FirstValue(self) -> int: 
        """
        Returns the first index
        """
    def IsAnalyzed(self) -> bool: 
        """
        Returns TRUE if the couple has been analyzed
        """
    def IsEqual(self,theOther : IntPolyh_Couple) -> bool: 
        """
        Returns true if the Couple is equal to <theOther>
        """
    def SecondValue(self) -> int: 
        """
        Returns the second index
        """
    def SetAnalyzed(self,theAnalyzed : bool) -> None: 
        """
        Sets the analyzed flag
        """
    def SetAngle(self,theAngle : float) -> None: 
        """
        Sets the angle
        """
    def SetCoupleValue(self,theInd1 : int,theInd2 : int) -> None: 
        """
        Sets the triangles
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theTriangle1 : int,theTriangle2 : int,theAngle : float=-2.0) -> None: ...
    pass
class IntPolyh_Edge():
    """
    The class represents the edge built between the two IntPolyh points. It is linked to two IntPolyh triangles.
    """
    def Dump(self,v : int) -> None: ...
    def FirstPoint(self) -> int: 
        """
        Returns the first point
        """
    def FirstTriangle(self) -> int: 
        """
        Returns the first triangle
        """
    def SecondPoint(self) -> int: 
        """
        Returns the second point
        """
    def SecondTriangle(self) -> int: 
        """
        Returns the second triangle
        """
    def SetFirstPoint(self,thePoint : int) -> None: 
        """
        Sets the first point
        """
    def SetFirstTriangle(self,theTriangle : int) -> None: 
        """
        Sets the first triangle
        """
    def SetSecondPoint(self,thePoint : int) -> None: 
        """
        Sets the second point
        """
    def SetSecondTriangle(self,theTriangle : int) -> None: 
        """
        Sets the second triangle
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,thePoint1 : int,thePoint2 : int,theTriangle1 : int,theTriangle2 : int) -> None: ...
    pass
class IntPolyh_Intersection():
    """
    API algorithm for intersection of two surfaces by intersection of their triangulations.
    """
    def GetLinePoint(self,IndexLine : int,IndexPoint : int) -> tuple[float, float, float, float, float, float, float, float]: 
        """
        Gets the parameters of the point in section line
        """
    def GetTangentZonePoint(self,IndexLine : int,IndexPoint : int) -> tuple[float, float, float, float, float, float, float]: 
        """
        Gets the parameters of the point in tangent zone
        """
    def IsDone(self) -> bool: 
        """
        Returns state of the operation
        """
    def IsParallel(self) -> bool: 
        """
        Returns state of the operation
        """
    def NbPointsInLine(self,IndexLine : int) -> int: 
        """
        Returns the number of points in the given line
        """
    def NbPointsInTangentZone(self,arg0 : int) -> int: 
        """
        Returns number of points in tangent zone
        """
    def NbSectionLines(self) -> int: 
        """
        Returns the number of section lines
        """
    def NbTangentZones(self) -> int: ...
    @overload
    def __init__(self,theS1 : OCP.Adaptor3d.Adaptor3d_Surface,theS2 : OCP.Adaptor3d.Adaptor3d_Surface) -> None: ...
    @overload
    def __init__(self,theS1 : OCP.Adaptor3d.Adaptor3d_Surface,theNbSU1 : int,theNbSV1 : int,theS2 : OCP.Adaptor3d.Adaptor3d_Surface,theNbSU2 : int,theNbSV2 : int) -> None: ...
    @overload
    def __init__(self,theS1 : OCP.Adaptor3d.Adaptor3d_Surface,theUPars1 : OCP.TColStd.TColStd_Array1OfReal,theVPars1 : OCP.TColStd.TColStd_Array1OfReal,theS2 : OCP.Adaptor3d.Adaptor3d_Surface,theUPars2 : OCP.TColStd.TColStd_Array1OfReal,theVPars2 : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    pass
class IntPolyh_ListOfCouples(OCP.NCollection.NCollection_BaseList):
    """
    Purpose: Simple list to link items together keeping the first and the last one. Inherits BaseList, adding the data item to each node.
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : IntPolyh_Couple) -> IntPolyh_Couple: 
        """
        Append one item at the end

        Append one item at the end and output iterator pointing at the appended item

        Append another list at the end. After this operation, theOther list will be cleared.
        """
    @overload
    def Append(self,theItem : IntPolyh_Couple,theIter : Any) -> None: ...
    @overload
    def Append(self,theOther : IntPolyh_ListOfCouples) -> None: ...
    def Assign(self,theOther : IntPolyh_ListOfCouples) -> IntPolyh_ListOfCouples: 
        """
        Replace this list by the items of another list (theOther parameter). This method does not change the internal allocator.
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear this list
        """
    def Extent(self) -> int: ...
    def First(self) -> IntPolyh_Couple: 
        """
        First item

        First item (non-const)
        """
    @overload
    def InsertAfter(self,theItem : IntPolyh_Couple,theIter : Any) -> IntPolyh_Couple: 
        """
        InsertAfter

        InsertAfter
        """
    @overload
    def InsertAfter(self,theOther : IntPolyh_ListOfCouples,theIter : Any) -> None: ...
    @overload
    def InsertBefore(self,theItem : IntPolyh_Couple,theIter : Any) -> IntPolyh_Couple: 
        """
        InsertBefore

        InsertBefore
        """
    @overload
    def InsertBefore(self,theOther : IntPolyh_ListOfCouples,theIter : Any) -> None: ...
    def IsEmpty(self) -> bool: ...
    def Last(self) -> IntPolyh_Couple: 
        """
        Last item

        Last item (non-const)
        """
    @overload
    def Prepend(self,theItem : IntPolyh_Couple) -> IntPolyh_Couple: 
        """
        Prepend one item at the beginning

        Prepend another list at the beginning
        """
    @overload
    def Prepend(self,theOther : IntPolyh_ListOfCouples) -> None: ...
    def Remove(self,theIter : Any) -> None: 
        """
        Remove item pointed by iterator theIter; theIter is then set to the next item
        """
    def RemoveFirst(self) -> None: 
        """
        RemoveFirst item
        """
    def Reverse(self) -> None: 
        """
        Reverse the list
        """
    def Size(self) -> int: 
        """
        Size - Number of items
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : IntPolyh_ListOfCouples) -> None: ...
    def __iter__(self) -> Iterator[IntPolyh_Couple]: ...
    def __len__(self) -> int: ...
    pass
class IntPolyh_MaillageAffinage():
    """
    Low-level algorithm to compute intersection of the surfaces by computing the intersection of their triangulations.
    """
    @overload
    def CommonBox(self) -> None: 
        """
        Looks for the common box of the surfaces and marks the points of the surfaces inside that common box for possible intersection

        Compute the common box witch is the intersection of the two bounding boxes, and mark the points of the two surfaces that are inside.
        """
    @overload
    def CommonBox(self,B1 : OCP.Bnd.Bnd_Box,B2 : OCP.Bnd.Bnd_Box) -> tuple[float, float, float, float, float, float]: ...
    def CommonPartRefinement(self) -> None: 
        """
        Refine systematicaly all marked triangles of both surfaces
        """
    def ComputeDeflections(self,SurfID : int) -> None: 
        """
        Compute deflection for all triangles of one surface,and sort min and max of deflections
        """
    def FillArrayOfEdges(self,SurfID : int) -> None: 
        """
        Compute edges from the array of points
        """
    @overload
    def FillArrayOfPnt(self,SurfID : int) -> None: 
        """
        Computes points on one surface and fills an array of points; standard (default) method

        isShiftFwd flag is added. The purpose is to define shift of points along normal to the surface in this point. The shift length represents maximal deflection of triangulation. The direction (forward or reversed regarding to normal direction) is defined by isShiftFwd flag. Compute points on one surface and fill an array of points; advanced method

        Compute points on one surface and fill an array of points; If given, <theDeflTol> is the deflection tolerance of the given sampling. standard (default) method

        isShiftFwd flag is added. The purpose is to define shift of points along normal to the surface in this point. The shift length represents maximal deflection of triangulation. The direction (forward or reversed regarding to normal direction) is defined by isShiftFwd flag. Compute points on one surface and fill an array of points; If given, <theDeflTol> is the deflection tolerance of the given sampling. advanced method

        Fills the array of points for the surface taking into account the shift
        """
    @overload
    def FillArrayOfPnt(self,SurfID : int,isShiftFwd : bool) -> None: ...
    @overload
    def FillArrayOfPnt(self,SurfID : int,Upars : OCP.TColStd.TColStd_Array1OfReal,Vpars : OCP.TColStd.TColStd_Array1OfReal,theDeflTol : float=None) -> None: ...
    @overload
    def FillArrayOfPnt(self,SurfID : int,isShiftFwd : bool,Upars : OCP.TColStd.TColStd_Array1OfReal,Vpars : OCP.TColStd.TColStd_Array1OfReal,theDeflTol : float=None) -> None: ...
    @overload
    def FillArrayOfPnt(self,SurfID : int,isShiftFwd : bool,thePoints : Any,theUPars : OCP.TColStd.TColStd_Array1OfReal,theVPars : OCP.TColStd.TColStd_Array1OfReal,theDeflTol : float) -> None: ...
    def FillArrayOfTriangles(self,SurfID : int) -> None: 
        """
        Compute triangles from the array of points, and -- mark the triangles that use marked points by the CommonBox function.
        """
    def GetArrayOfEdges(self,SurfID : int) -> Any: ...
    def GetArrayOfPoints(self,SurfID : int) -> Any: ...
    def GetArrayOfTriangles(self,SurfID : int) -> Any: ...
    def GetBox(self,SurfID : int) -> OCP.Bnd.Bnd_Box: ...
    def GetCouples(self) -> IntPolyh_ListOfCouples: 
        """
        This method returns list of couples of contact triangles.
        """
    def GetEnlargeZone(self) -> bool: ...
    def GetMaxDeflection(self,SurfID : int) -> float: 
        """
        returns FlecheMax
        """
    def GetMinDeflection(self,SurfID : int) -> float: 
        """
        returns FlecheMin
        """
    def GetNextChainStartPoint(self,SPInit : IntPolyh_StartPoint,SPNext : IntPolyh_StartPoint,MySectionLine : IntPolyh_SectionLine,TTangentZones : Any,Prepend : bool=False) -> int: 
        """
        Mainly used by StartPointsChain(), this function try to compute the next StartPoint.
        """
    def LocalSurfaceRefinement(self,SurfId : int) -> None: 
        """
        Refine systematicaly all marked triangles of ONE surface
        """
    def MakeSampling(self,SurfID : int,theUPars : OCP.TColStd.TColStd_Array1OfReal,theVPars : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Makes the sampling of the surface - Fills the arrays with the parametric values of the sampling points (triangulation nodes).
        """
    def NextStartingPointsResearch(self,T1 : int,T2 : int,SPInit : IntPolyh_StartPoint,SPNext : IntPolyh_StartPoint) -> int: 
        """
        from two triangles and an intersection point I search the other point (if it exists). This function is used by StartPointChain
        """
    def SetEnlargeZone(self,EnlargeZone : bool) -> None: ...
    def StartPointsChain(self,TSectionLines : Any,TTangentZones : Any) -> int: 
        """
        Loop on the array of couples. Compute StartPoints. Try to chain the StartPoints into SectionLines or put the point in the ArrayOfTangentZones if chaining it, is not possible.
        """
    def StartingPointsResearch(self,T1 : int,T2 : int,SP1 : IntPolyh_StartPoint,SP2 : IntPolyh_StartPoint) -> int: 
        """
        From two triangles compute intersection points. If we found more than two intersection points that means that those triangles are coplanar
        """
    def TriContact(self,P1 : IntPolyh_Point,P2 : IntPolyh_Point,P3 : IntPolyh_Point,Q1 : IntPolyh_Point,Q2 : IntPolyh_Point,Q3 : IntPolyh_Point,Angle : float) -> int: 
        """
        This function checks if two triangles are in contact or not, return 1 if yes, return 0 if not.
        """
    def TriangleCompare(self) -> int: 
        """
        Analyse each couple of triangles from the two -- array of triangles, to see if they are in contact, and compute the incidence. Then put couples in contact in the array of couples
        """
    def TriangleEdgeContact(self,TriSurfID : int,EdgeIndice : int,Tri1 : IntPolyh_Triangle,Tri2 : IntPolyh_Triangle,P1 : IntPolyh_Point,P2 : IntPolyh_Point,P3 : IntPolyh_Point,C1 : IntPolyh_Point,C2 : IntPolyh_Point,C3 : IntPolyh_Point,Pe1 : IntPolyh_Point,Pe2 : IntPolyh_Point,E : IntPolyh_Point,N : IntPolyh_Point,SP1 : IntPolyh_StartPoint,SP2 : IntPolyh_StartPoint) -> int: ...
    def TrianglesDeflectionsRefinementBSB(self) -> None: 
        """
        Refine both surfaces using BoundSortBox as -- rejection. The criterions used to refine a -- triangle are: The deflection The size of the -- bounding boxes (one surface may be very small compared to the other)
        """
    @overload
    def __init__(self,S1 : OCP.Adaptor3d.Adaptor3d_Surface,NbSU1 : int,NbSV1 : int,S2 : OCP.Adaptor3d.Adaptor3d_Surface,NbSU2 : int,NbSV2 : int,PRINT : int) -> None: ...
    @overload
    def __init__(self,S1 : OCP.Adaptor3d.Adaptor3d_Surface,S2 : OCP.Adaptor3d.Adaptor3d_Surface,PRINT : int) -> None: ...
    pass
class IntPolyh_Point():
    """
    The class represents the point on the surface with both 3D and 2D points.
    """
    def Add(self,P1 : IntPolyh_Point) -> IntPolyh_Point: 
        """
        Addition
        """
    def Cross(self,P1 : IntPolyh_Point,P2 : IntPolyh_Point) -> None: 
        """
        Cross
        """
    def Degenerated(self) -> bool: 
        """
        Returns the degenerated flag
        """
    def Divide(self,rr : float) -> IntPolyh_Point: 
        """
        Division
        """
    def Dot(self,P2 : IntPolyh_Point) -> float: 
        """
        Dot
        """
    @overload
    def Dump(self) -> None: 
        """
        Dump

        Dump
        """
    @overload
    def Dump(self,i : int) -> None: ...
    def Middle(self,MySurface : OCP.Adaptor3d.Adaptor3d_Surface,P1 : IntPolyh_Point,P2 : IntPolyh_Point) -> None: 
        """
        Creates middle point from P1 and P2 and stores it to this
        """
    def Multiplication(self,rr : float) -> IntPolyh_Point: 
        """
        Multiplication
        """
    def PartOfCommon(self) -> int: 
        """
        Returns 0 if the point is not common with the other surface
        """
    def Set(self,x : float,y : float,z : float,u : float,v : float,II : int=1) -> None: 
        """
        Sets the point
        """
    def SetDegenerated(self,theFlag : bool) -> None: 
        """
        Sets the degenerated flag
        """
    def SetPartOfCommon(self,ii : int) -> None: 
        """
        Sets the part of common
        """
    def SetU(self,u : float) -> None: 
        """
        Sets the U coordinate for the 2D point
        """
    def SetV(self,v : float) -> None: 
        """
        Sets the V coordinate for the 2D point
        """
    def SetX(self,x : float) -> None: 
        """
        Sets the X coordinate for the 3D point
        """
    def SetY(self,y : float) -> None: 
        """
        Sets the Y coordinate for the 3D point
        """
    def SetZ(self,z : float) -> None: 
        """
        Sets the Z coordinate for the 3D point
        """
    def SquareDistance(self,P2 : IntPolyh_Point) -> float: 
        """
        Square distance to the other point
        """
    def SquareModulus(self) -> float: 
        """
        Square modulus
        """
    def Sub(self,P1 : IntPolyh_Point) -> IntPolyh_Point: 
        """
        Subtraction
        """
    def U(self) -> float: 
        """
        Returns the U coordinate of the 2D point
        """
    def V(self) -> float: 
        """
        Returns the V coordinate of the 2D point
        """
    def X(self) -> float: 
        """
        Returns X coordinate of the 3D point
        """
    def Y(self) -> float: 
        """
        Returns Y coordinate of the 3D point
        """
    def Z(self) -> float: 
        """
        Returns the Z coordinate of the 3D point
        """
    def __add__(self,P1 : IntPolyh_Point) -> IntPolyh_Point: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,x : float,y : float,z : float,u : float,v : float) -> None: ...
    def __mul__(self,rr : float) -> IntPolyh_Point: ...
    def __rmul__(self,rr : float) -> IntPolyh_Point: ...
    def __sub__(self,P1 : IntPolyh_Point) -> IntPolyh_Point: ...
    def __truediv__(self,rr : float) -> IntPolyh_Point: ...
    pass
class IntPolyh_PointNormal():
    """
    Auxiliary structure to represent pair of point and normal vector in this point on the surface.
    """
    def __init__(self) -> None: ...
    @property
    def Normal(self) -> OCP.gp.gp_Vec:
        """
        :type: OCP.gp.gp_Vec
        """
    @Normal.setter
    def Normal(self, arg0: OCP.gp.gp_Vec) -> None:
        pass
    @property
    def Point(self) -> OCP.gp.gp_Pnt:
        """
        :type: OCP.gp.gp_Pnt
        """
    @Point.setter
    def Point(self, arg0: OCP.gp.gp_Pnt) -> None:
        pass
    pass
class IntPolyh_SectionLine():
    def ChangeValue(self,nn : int) -> IntPolyh_StartPoint: ...
    def Copy(self,Other : IntPolyh_SectionLine) -> IntPolyh_SectionLine: ...
    def Destroy(self) -> None: ...
    def Dump(self) -> None: ...
    def GetN(self) -> int: ...
    def IncrementNbStartPoints(self) -> None: ...
    def Init(self,nn : int) -> None: ...
    def NbStartPoints(self) -> int: ...
    def Prepend(self,SP : IntPolyh_StartPoint) -> None: ...
    def Value(self,nn : int) -> IntPolyh_StartPoint: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,nn : int) -> None: ...
    @overload
    def __init__(self,theOther : IntPolyh_SectionLine) -> None: ...
    pass
class IntPolyh_SeqOfStartPoints(OCP.NCollection.NCollection_BaseSequence):
    """
    Purpose: Definition of a sequence of elements indexed by an Integer in range of 1..n
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : IntPolyh_StartPoint) -> None: 
        """
        Append one item

        Append another sequence (making it empty)
        """
    @overload
    def Append(self,theSeq : IntPolyh_SeqOfStartPoints) -> None: ...
    def Assign(self,theOther : IntPolyh_SeqOfStartPoints) -> IntPolyh_SeqOfStartPoints: 
        """
        Replace this sequence by the items of theOther. This method does not change the internal allocator.
        """
    def ChangeFirst(self) -> IntPolyh_StartPoint: 
        """
        First item access
        """
    def ChangeLast(self) -> IntPolyh_StartPoint: 
        """
        Last item access
        """
    def ChangeValue(self,theIndex : int) -> IntPolyh_StartPoint: 
        """
        Variable item access by theIndex
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear the items out, take a new allocator if non null
        """
    def Exchange(self,I : int,J : int) -> None: 
        """
        Exchange two members
        """
    def First(self) -> IntPolyh_StartPoint: 
        """
        First item access
        """
    @overload
    def InsertAfter(self,theIndex : int,theSeq : IntPolyh_SeqOfStartPoints) -> None: 
        """
        InsertAfter theIndex another sequence (making it empty)

        InsertAfter theIndex theItem
        """
    @overload
    def InsertAfter(self,theIndex : int,theItem : IntPolyh_StartPoint) -> None: ...
    @overload
    def InsertBefore(self,theIndex : int,theItem : IntPolyh_StartPoint) -> None: 
        """
        InsertBefore theIndex theItem

        InsertBefore theIndex another sequence (making it empty)
        """
    @overload
    def InsertBefore(self,theIndex : int,theSeq : IntPolyh_SeqOfStartPoints) -> None: ...
    def IsEmpty(self) -> bool: 
        """
        Empty query
        """
    def Last(self) -> IntPolyh_StartPoint: 
        """
        Last item access
        """
    def Length(self) -> int: 
        """
        Number of items
        """
    def Lower(self) -> int: 
        """
        Method for consistency with other collections.
        """
    @overload
    def Prepend(self,theItem : IntPolyh_StartPoint) -> None: 
        """
        Prepend one item

        Prepend another sequence (making it empty)
        """
    @overload
    def Prepend(self,theSeq : IntPolyh_SeqOfStartPoints) -> None: ...
    @overload
    def Remove(self,theIndex : int) -> None: 
        """
        Remove one item

        Remove range of items
        """
    @overload
    def Remove(self,theFromIndex : int,theToIndex : int) -> None: ...
    def Reverse(self) -> None: 
        """
        Reverse sequence
        """
    def SetValue(self,theIndex : int,theItem : IntPolyh_StartPoint) -> None: 
        """
        Set item value by theIndex
        """
    def Size(self) -> int: 
        """
        Number of items
        """
    def Split(self,theIndex : int,theSeq : IntPolyh_SeqOfStartPoints) -> None: 
        """
        Split in two sequences
        """
    def Upper(self) -> int: 
        """
        Method for consistency with other collections.
        """
    def Value(self,theIndex : int) -> IntPolyh_StartPoint: 
        """
        Constant item access by theIndex
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> IntPolyh_StartPoint: 
        """
        Constant operator()

        Variable operator()
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : IntPolyh_SeqOfStartPoints) -> None: ...
    def __iter__(self) -> Iterator[IntPolyh_StartPoint]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def delNode_s(theNode : NCollection_SeqNode,theAl : OCP.NCollection.NCollection_BaseAllocator) -> None: 
        """
        Static deleter to be passed to BaseSequence
        """
    pass
class IntPolyh_StartPoint():
    def ChainList(self) -> int: ...
    def CheckSameSP(self,SP : IntPolyh_StartPoint) -> int: ...
    @overload
    def Dump(self) -> None: ...
    @overload
    def Dump(self,i : int) -> None: ...
    def E1(self) -> int: ...
    def E2(self) -> int: ...
    def GetAngle(self) -> float: ...
    def GetEdgePoints(self,Triangle : IntPolyh_Triangle,FirstEdgePoint : int,SecondEdgePoint : int,LastPoint : int) -> int: ...
    def Lambda1(self) -> float: ...
    def Lambda2(self) -> float: ...
    def SetAngle(self,ang : float) -> None: ...
    def SetChainList(self,ChList : int) -> None: ...
    def SetCoupleValue(self,IT1 : int,IT2 : int) -> None: ...
    def SetEdge1(self,IE1 : int) -> None: ...
    def SetEdge2(self,IE2 : int) -> None: ...
    def SetLambda1(self,LAM1 : float) -> None: ...
    def SetLambda2(self,LAM2 : float) -> None: ...
    def SetUV1(self,UU1 : float,VV1 : float) -> None: ...
    def SetUV2(self,UU2 : float,VV2 : float) -> None: ...
    def SetXYZ(self,XX : float,YY : float,ZZ : float) -> None: ...
    def T1(self) -> int: ...
    def T2(self) -> int: ...
    def U1(self) -> float: ...
    def U2(self) -> float: ...
    def V1(self) -> float: ...
    def V2(self) -> float: ...
    def X(self) -> float: ...
    def Y(self) -> float: ...
    def Z(self) -> float: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,xx : float,yy : float,zz : float,uu1 : float,vv1 : float,uu2 : float,vv2 : float,T1 : int,E1 : int,LAM1 : float,T2 : int,E2 : int,LAM2 : float,List : int) -> None: ...
    pass
class IntPolyh_Tools():
    """
    The class provides tools for surface sampling.
    """
    @staticmethod
    def ComputeDeflection_s(theSurf : OCP.Adaptor3d.Adaptor3d_Surface,theUPars : OCP.TColStd.TColStd_Array1OfReal,theVPars : OCP.TColStd.TColStd_Array1OfReal) -> float: 
        """
        Computes the deflection tolerance on the surface for the given sampling.
        """
    @staticmethod
    def FillArrayOfPointNormal_s(theSurf : OCP.Adaptor3d.Adaptor3d_Surface,theUPars : OCP.TColStd.TColStd_Array1OfReal,theVPars : OCP.TColStd.TColStd_Array1OfReal,thePoints : Any) -> None: 
        """
        Fills the array <thePoints> with the points (triangulation nodes) on the surface and normal directions of the surface in these points.
        """
    @staticmethod
    def IsEnlargePossible_s(theSurf : OCP.Adaptor3d.Adaptor3d_Surface) -> tuple[bool, bool]: 
        """
        Checks if the surface can be enlarged in U or V direction.
        """
    @staticmethod
    def MakeSampling_s(theSurf : OCP.Adaptor3d.Adaptor3d_Surface,theNbSU : int,theNbSV : int,theEnlargeZone : bool,theUPars : OCP.TColStd.TColStd_Array1OfReal,theVPars : OCP.TColStd.TColStd_Array1OfReal) -> None: 
        """
        Makes the sampling of the given surface <theSurf> making the net of <theNbSU> x <theNbSV> sampling points. The flag <theEnlargeZone> controls the enlargement of the sampling zone on the surface. The parameters of the sampling points are stored into <theUPars> and <theVPars> arrays.
        """
    def __init__(self) -> None: ...
    pass
class IntPolyh_Triangle():
    """
    The class represents the triangle built from three IntPolyh points and three IntPolyh edges.
    """
    def BoundingBox(self,thePoints : Any) -> OCP.Bnd.Bnd_Box: 
        """
        Returns the bounding box of the triangle.
        """
    def ComputeDeflection(self,theSurface : OCP.Adaptor3d.Adaptor3d_Surface,thePoints : Any) -> float: 
        """
        Computes the deflection for the triangle
        """
    def Deflection(self) -> float: 
        """
        Returns the deflection of the triangle
        """
    def Dump(self,v : int) -> None: 
        """
        Dumps the contents of the triangle.
        """
    def FirstEdge(self) -> int: 
        """
        Returns the first edge
        """
    def FirstEdgeOrientation(self) -> int: 
        """
        Returns the orientation of the first edge
        """
    def FirstPoint(self) -> int: 
        """
        Returns the first point
        """
    def GetEdgeNumber(self,theEdgeIndex : int) -> int: 
        """
        Gets the edge number by the index
        """
    def GetEdgeOrientation(self,theEdgeIndex : int) -> int: 
        """
        Gets the edges orientation by the index
        """
    def GetNextTriangle(self,theTriangle : int,theEdgeNum : int,TEdges : Any) -> int: 
        """
        Gets the adjacent triangle
        """
    def HasIntersection(self) -> bool: 
        """
        Returns true if the triangle has interfered the other triangle
        """
    def IsDegenerated(self) -> bool: 
        """
        Returns the Degenerated flag
        """
    def IsIntersectionPossible(self) -> bool: 
        """
        Returns possibility of the intersection
        """
    def LinkEdges2Triangle(self,TEdges : Any,theEdge1 : int,theEdge2 : int,theEdge3 : int) -> None: 
        """
        Links edges to triangle
        """
    def MiddleRefinement(self,theTriangleNumber : int,theSurface : OCP.Adaptor3d.Adaptor3d_Surface,TPoints : Any,TTriangles : Any,TEdges : Any) -> None: 
        """
        Splits the triangle on two to decrease its deflection
        """
    def MultipleMiddleRefinement(self,theRefineCriterion : float,theBox : OCP.Bnd.Bnd_Box,theTriangleNumber : int,theSurface : OCP.Adaptor3d.Adaptor3d_Surface,TPoints : Any,TTriangles : Any,TEdges : Any) -> None: 
        """
        Splits the current triangle and new triangles until the refinement criterion is not achieved
        """
    def SecondEdge(self) -> int: 
        """
        Returns the second edge
        """
    def SecondEdgeOrientation(self) -> int: 
        """
        Returns the orientation of the second edge
        """
    def SecondPoint(self) -> int: 
        """
        Returns the second point
        """
    def SetDeflection(self,theDeflection : float) -> None: 
        """
        Sets the deflection
        """
    def SetDegenerated(self,theDegFlag : bool) -> None: 
        """
        Sets the degenerated flag
        """
    def SetEdge(self,theEdgeIndex : int,theEdgeNumber : int) -> None: 
        """
        Sets the edge by the index
        """
    def SetEdgeAndOrientation(self,theEdge : IntPolyh_Edge,theEdgeIndex : int) -> None: 
        """
        Sets the appropriate edge and orientation for the triangle.
        """
    def SetEdgeOrientation(self,theEdgeIndex : int,theEdgeOrientation : int) -> None: 
        """
        Sets the edges orientation by the index
        """
    def SetFirstEdge(self,theEdge : int,theEdgeOrientation : int) -> None: 
        """
        Sets the first edge
        """
    def SetFirstPoint(self,thePoint : int) -> None: 
        """
        Sets the first point
        """
    def SetIntersection(self,theInt : bool) -> None: 
        """
        Sets the flag of intersection
        """
    def SetIntersectionPossible(self,theIP : bool) -> None: 
        """
        Sets the flag of possibility of intersection
        """
    def SetSecondEdge(self,theEdge : int,theEdgeOrientation : int) -> None: 
        """
        Sets the second edge
        """
    def SetSecondPoint(self,thePoint : int) -> None: 
        """
        Sets the second point
        """
    def SetThirdEdge(self,theEdge : int,theEdgeOrientation : int) -> None: 
        """
        Sets the third edge
        """
    def SetThirdPoint(self,thePoint : int) -> None: 
        """
        Sets the third point
        """
    def ThirdEdge(self) -> int: 
        """
        Returns the third edge
        """
    def ThirdEdgeOrientation(self) -> int: 
        """
        Returns the orientation of the third edge
        """
    def ThirdPoint(self) -> int: 
        """
        Returns the third point
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,thePoint1 : int,thePoint2 : int,thePoint3 : int) -> None: ...
    pass



import OCP.Sweep
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TopAbs
__all__  = [
"Sweep_NumShape",
"Sweep_NumShapeIterator",
"Sweep_NumShapeTool"
]
class Sweep_NumShape():
    """
    Gives a simple indexed representation of a Directing Edge topology.
    """
    def BegInfinite(self) -> bool: ...
    def Closed(self) -> bool: ...
    def EndInfinite(self) -> bool: ...
    def Index(self) -> int: ...
    def Init(self,Index : int,Type : OCP.TopAbs.TopAbs_ShapeEnum,Closed : bool=False,BegInf : bool=False,EndInf : bool=False) -> None: 
        """
        Reinitialize a simple indexed edge.
        """
    def Orientation(self) -> OCP.TopAbs.TopAbs_Orientation: ...
    def Type(self) -> OCP.TopAbs.TopAbs_ShapeEnum: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,Index : int,Type : OCP.TopAbs.TopAbs_ShapeEnum,Closed : bool=False,BegInf : bool=False,EndInf : bool=False) -> None: ...
    pass
class Sweep_NumShapeIterator():
    """
    This class provides iteration services required by the Swept Primitives for a Directing NumShape Line.
    """
    def Init(self,aShape : Sweep_NumShape) -> None: 
        """
        Reset the NumShapeIterator on sub-shapes of <aShape>.
        """
    def More(self) -> bool: 
        """
        Returns True if there is a current sub-shape.

        Returns True if there is a current sub-shape.
        """
    def Next(self) -> None: 
        """
        Moves to the next sub-shape.
        """
    def Orientation(self) -> OCP.TopAbs.TopAbs_Orientation: 
        """
        Returns the orientation of the current sub-shape.

        Returns the orientation of the current sub-shape.
        """
    def Value(self) -> Sweep_NumShape: 
        """
        Returns the current sub-shape.

        Returns the current sub-shape.
        """
    def __init__(self) -> None: ...
    pass
class Sweep_NumShapeTool():
    """
    This class provides the indexation and type analysis services required by the NumShape Directing Shapes of Swept Primitives.
    """
    def FirstVertex(self) -> Sweep_NumShape: 
        """
        Returns the first vertex.
        """
    def HasFirstVertex(self) -> bool: 
        """
        Returns true if there is a First Vertex in the Shape.
        """
    def HasLastVertex(self) -> bool: 
        """
        Returns true if there is a Last Vertex in the Shape.
        """
    def Index(self,aShape : Sweep_NumShape) -> int: 
        """
        Returns the index of <aShape>.
        """
    def LastVertex(self) -> Sweep_NumShape: 
        """
        Returns the last vertex.
        """
    def NbShapes(self) -> int: 
        """
        Returns the number of subshapes in the shape.
        """
    def Orientation(self,aShape : Sweep_NumShape) -> OCP.TopAbs.TopAbs_Orientation: 
        """
        Returns the orientation of <aShape>.
        """
    def Shape(self,anIndex : int) -> Sweep_NumShape: 
        """
        Returns the Shape at index anIndex
        """
    def Type(self,aShape : Sweep_NumShape) -> OCP.TopAbs.TopAbs_ShapeEnum: 
        """
        Returns the type of <aShape>.
        """
    def __init__(self,aShape : Sweep_NumShape) -> None: ...
    pass



import OCP.IMeshTools
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import OCP.gp
import OCP.IMeshData
import OCP.TopoDS
import OCP.Message
import OCP.TColStd
import OCP.Standard
import OCP.GeomAbs
__all__  = [
"IMeshTools_Context",
"IMeshTools_CurveTessellator",
"IMeshTools_MeshAlgo",
"IMeshTools_MeshAlgoFactory",
"IMeshTools_MeshAlgoType",
"IMeshTools_MeshBuilder",
"IMeshTools_ModelAlgo",
"IMeshTools_ModelBuilder",
"IMeshTools_Parameters",
"IMeshTools_ShapeExplorer",
"IMeshTools_ShapeVisitor",
"IMeshTools_MeshAlgoType_DEFAULT",
"IMeshTools_MeshAlgoType_Delabella",
"IMeshTools_MeshAlgoType_Watson"
]
class IMeshTools_Context(OCP.IMeshData.IMeshData_Shape, OCP.Standard.Standard_Transient):
    """
    Interface class representing context of BRepMesh algorithm. Intended to cache discrete model and instances of tools for its processing.
    """
    def BuildModel(self) -> bool: 
        """
        Builds model using assigned model builder.
        """
    def ChangeParameters(self) -> IMeshTools_Parameters: 
        """
        Gets reference to parameters to be used for meshing.
        """
    def Clean(self) -> None: 
        """
        Cleans temporary context data.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DiscretizeEdges(self) -> bool: 
        """
        Performs discretization of model edges using assigned edge discret algorithm.
        """
    def DiscretizeFaces(self,theRange : OCP.Message.Message_ProgressRange) -> bool: 
        """
        Performs meshing of faces of discrete model using assigned meshing algorithm.
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetEdgeDiscret(self) -> IMeshTools_ModelAlgo: 
        """
        Gets instance of a tool to be used to discretize edges of a model.
        """
    def GetFaceDiscret(self) -> IMeshTools_ModelAlgo: 
        """
        Gets instance of meshing algorithm.
        """
    def GetModel(self) -> OCP.IMeshData.IMeshData_Model: 
        """
        Returns discrete model of a shape.
        """
    def GetModelBuilder(self) -> IMeshTools_ModelBuilder: 
        """
        Gets instance of a tool to be used to build discrete model.
        """
    def GetModelHealer(self) -> IMeshTools_ModelAlgo: 
        """
        Gets instance of a tool to be used to heal discrete model.
        """
    def GetParameters(self) -> IMeshTools_Parameters: 
        """
        Gets parameters to be used for meshing.
        """
    def GetPostProcessor(self) -> IMeshTools_ModelAlgo: 
        """
        Gets instance of post-processing algorithm.
        """
    def GetPreProcessor(self) -> IMeshTools_ModelAlgo: 
        """
        Gets instance of pre-processing algorithm.
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetShape(self) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns shape assigned to discrete shape.
        """
    def HealModel(self) -> bool: 
        """
        Performs healing of discrete model built by DiscretizeEdges() method using assigned healing algorithm.
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def PostProcessModel(self) -> bool: 
        """
        Performs post-processing of discrete model using assigned algorithm.
        """
    def PreProcessModel(self) -> bool: 
        """
        Performs pre-processing of discrete model using assigned algorithm. Performs auxiliary actions such as cleaning shape from old triangulation.
        """
    def SetEdgeDiscret(self,theEdgeDiscret : IMeshTools_ModelAlgo) -> None: 
        """
        Sets instance of a tool to be used to discretize edges of a model.
        """
    def SetFaceDiscret(self,theFaceDiscret : IMeshTools_ModelAlgo) -> None: 
        """
        Sets instance of meshing algorithm.
        """
    def SetModelBuilder(self,theBuilder : IMeshTools_ModelBuilder) -> None: 
        """
        Sets instance of a tool to be used to build discrete model.
        """
    def SetModelHealer(self,theModelHealer : IMeshTools_ModelAlgo) -> None: 
        """
        Sets instance of a tool to be used to heal discrete model.
        """
    def SetPostProcessor(self,thePostProcessor : IMeshTools_ModelAlgo) -> None: 
        """
        Sets instance of post-processing algorithm.
        """
    def SetPreProcessor(self,thePreProcessor : IMeshTools_ModelAlgo) -> None: 
        """
        Sets instance of pre-processing algorithm.
        """
    def SetShape(self,theShape : OCP.TopoDS.TopoDS_Shape) -> None: 
        """
        Assigns shape to discrete shape.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class IMeshTools_CurveTessellator(OCP.Standard.Standard_Transient):
    """
    Interface class providing API for edge tessellation tools.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def PointsNb(self) -> int: 
        """
        Returns number of tessellation points.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Value(self,theIndex : int,thePoint : OCP.gp.gp_Pnt,theParameter : float) -> bool: 
        """
        Returns parameters of solution with the given index.
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class IMeshTools_MeshAlgo(OCP.Standard.Standard_Transient):
    """
    Interface class providing API for algorithms intended to create mesh for discrete face.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Perform(self,theDFace : OCP.IMeshData.IMeshData_Face,theParameters : IMeshTools_Parameters,theRange : OCP.Message.Message_ProgressRange) -> None: 
        """
        Performs processing of the given face.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class IMeshTools_MeshAlgoFactory(OCP.Standard.Standard_Transient):
    """
    Base interface for factories producing instances of triangulation algorithms taking into account type of surface of target face.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetAlgo(self,theSurfaceType : OCP.GeomAbs.GeomAbs_SurfaceType,theParameters : IMeshTools_Parameters) -> IMeshTools_MeshAlgo: 
        """
        Creates instance of meshing algorithm for the given type of surface.
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class IMeshTools_MeshAlgoType():
    """
    Enumerates built-in meshing algorithms factories implementing IMeshTools_MeshAlgoFactory interface.

    Members:

      IMeshTools_MeshAlgoType_DEFAULT

      IMeshTools_MeshAlgoType_Watson

      IMeshTools_MeshAlgoType_Delabella
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    IMeshTools_MeshAlgoType_DEFAULT: OCP.IMeshTools.IMeshTools_MeshAlgoType # value = <IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_DEFAULT: -1>
    IMeshTools_MeshAlgoType_Delabella: OCP.IMeshTools.IMeshTools_MeshAlgoType # value = <IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_Delabella: 1>
    IMeshTools_MeshAlgoType_Watson: OCP.IMeshTools.IMeshTools_MeshAlgoType # value = <IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_Watson: 0>
    __entries: dict # value = {'IMeshTools_MeshAlgoType_DEFAULT': (<IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_DEFAULT: -1>, None), 'IMeshTools_MeshAlgoType_Watson': (<IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_Watson: 0>, None), 'IMeshTools_MeshAlgoType_Delabella': (<IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_Delabella: 1>, None)}
    __members__: dict # value = {'IMeshTools_MeshAlgoType_DEFAULT': <IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_DEFAULT: -1>, 'IMeshTools_MeshAlgoType_Watson': <IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_Watson: 0>, 'IMeshTools_MeshAlgoType_Delabella': <IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_Delabella: 1>}
    pass
class IMeshTools_MeshBuilder(OCP.Message.Message_Algorithm, OCP.Standard.Standard_Transient):
    """
    Builds mesh for each face of shape without triangulation. In case if some faces of shape have already been triangulated checks deflection of existing polygonal model and re-uses it if deflection satisfies the specified parameter. Otherwise nullifies existing triangulation and build triangulation anew.
    """
    @overload
    def AddStatus(self,theOther : OCP.Message.Message_Algorithm) -> None: 
        """
        Add statuses to this algorithm from other algorithm (including messages)

        Add statuses to this algorithm from other algorithm, but only those items are moved that correspond to statuses set in theStatus
        """
    @overload
    def AddStatus(self,theStatus : OCP.Message.Message_ExecStatus,theOther : OCP.Message.Message_Algorithm) -> None: ...
    def ChangeStatus(self) -> OCP.Message.Message_ExecStatus: 
        """
        Returns exec status of algorithm

        Returns exec status of algorithm
        """
    def ClearStatus(self) -> None: 
        """
        Clear exec status of algorithm
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetContext(self) -> IMeshTools_Context: 
        """
        Gets context of algorithm.
        """
    def GetMessageNumbers(self,theStatus : OCP.Message.Message_Status) -> OCP.TColStd.TColStd_HPackedMapOfInteger: 
        """
        Return the numbers associated with the indicated status; Null handle if no such status or no numbers associated with it
        """
    def GetMessageStrings(self,theStatus : OCP.Message.Message_Status) -> OCP.TColStd.TColStd_HSequenceOfHExtendedString: 
        """
        Return the strings associated with the indicated status; Null handle if no such status or no strings associated with it
        """
    def GetMessenger(self) -> OCP.Message.Message_Messenger: 
        """
        Returns messenger of algorithm. The returned handle is always non-null and can be used for sending messages.

        Returns messenger of algorithm. The returned handle is always non-null and can be used for sending messages.
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetStatus(self) -> OCP.Message.Message_ExecStatus: 
        """
        Returns copy of exec status of algorithm

        Returns copy of exec status of algorithm
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Perform(self,theRange : OCP.Message.Message_ProgressRange) -> None: 
        """
        Performs meshing to the shape using current context.
        """
    @staticmethod
    @overload
    def PrepareReport_s(theError : OCP.TColStd.TColStd_HPackedMapOfInteger,theMaxCount : int) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        Prepares a string containing a list of integers contained in theError map, but not more than theMaxCount

        Prepares a string containing a list of names contained in theReportSeq sequence, but not more than theMaxCount
        """
    @staticmethod
    @overload
    def PrepareReport_s(theReportSeq : OCP.TColStd.TColStd_SequenceOfHExtendedString,theMaxCount : int) -> OCP.TCollection.TCollection_ExtendedString: ...
    def SendMessages(self,theTraceLevel : OCP.Message.Message_Gravity=Message_Gravity.Message_Warning,theMaxCount : int=20) -> None: 
        """
        Convenient variant of SendStatusMessages() with theFilter having defined all WARN, ALARM, and FAIL (but not DONE) status flags
        """
    def SendStatusMessages(self,theFilter : OCP.Message.Message_ExecStatus,theTraceLevel : OCP.Message.Message_Gravity=Message_Gravity.Message_Warning,theMaxCount : int=20) -> None: 
        """
        Print messages for all status flags that have been set during algorithm execution, excluding statuses that are NOT set in theFilter.
        """
    def SetContext(self,theContext : IMeshTools_Context) -> None: 
        """
        Sets context for algorithm.
        """
    def SetMessenger(self,theMsgr : OCP.Message.Message_Messenger) -> None: 
        """
        Sets messenger to algorithm
        """
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status) -> None: 
        """
        Sets status with no parameter

        Sets status with integer parameter

        Sets status with string parameter. If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with string parameter If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with string parameter If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with string parameter If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with string parameter If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with preformatted message. This message will be used directly to report the status; automatic generation of status messages will be disabled for it.

        Sets status with string parameter. If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with string parameter If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with string parameter If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with string parameter If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag
        """
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theInt : int) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : str,noRepetitions : bool=True) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : OCP.TCollection.TCollection_AsciiString,noRepetitions : bool=True) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : OCP.TCollection.TCollection_HAsciiString,noRepetitions : bool=True) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : OCP.TCollection.TCollection_ExtendedString,noRepetitions : bool=True) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : OCP.TCollection.TCollection_HExtendedString,noRepetitions : bool=True) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theMsg : OCP.Message.Message_Msg) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : str,noRepetitions : bool) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : OCP.TCollection.TCollection_AsciiString,noRepetitions : bool) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : OCP.TCollection.TCollection_HAsciiString,noRepetitions : bool) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : OCP.TCollection.TCollection_ExtendedString,noRepetitions : bool) -> None: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theContext : IMeshTools_Context) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class IMeshTools_ModelAlgo(OCP.Standard.Standard_Transient):
    """
    Interface class providing API for algorithms intended to update or modify discrete model.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Perform(self,theModel : OCP.IMeshData.IMeshData_Model,theParameters : IMeshTools_Parameters,theRange : OCP.Message.Message_ProgressRange) -> bool: 
        """
        Exceptions protected processing of the given model.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class IMeshTools_ModelBuilder(OCP.Message.Message_Algorithm, OCP.Standard.Standard_Transient):
    """
    Interface class represents API for tool building discrete model.
    """
    @overload
    def AddStatus(self,theOther : OCP.Message.Message_Algorithm) -> None: 
        """
        Add statuses to this algorithm from other algorithm (including messages)

        Add statuses to this algorithm from other algorithm, but only those items are moved that correspond to statuses set in theStatus
        """
    @overload
    def AddStatus(self,theStatus : OCP.Message.Message_ExecStatus,theOther : OCP.Message.Message_Algorithm) -> None: ...
    def ChangeStatus(self) -> OCP.Message.Message_ExecStatus: 
        """
        Returns exec status of algorithm

        Returns exec status of algorithm
        """
    def ClearStatus(self) -> None: 
        """
        Clear exec status of algorithm
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetMessageNumbers(self,theStatus : OCP.Message.Message_Status) -> OCP.TColStd.TColStd_HPackedMapOfInteger: 
        """
        Return the numbers associated with the indicated status; Null handle if no such status or no numbers associated with it
        """
    def GetMessageStrings(self,theStatus : OCP.Message.Message_Status) -> OCP.TColStd.TColStd_HSequenceOfHExtendedString: 
        """
        Return the strings associated with the indicated status; Null handle if no such status or no strings associated with it
        """
    def GetMessenger(self) -> OCP.Message.Message_Messenger: 
        """
        Returns messenger of algorithm. The returned handle is always non-null and can be used for sending messages.

        Returns messenger of algorithm. The returned handle is always non-null and can be used for sending messages.
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetStatus(self) -> OCP.Message.Message_ExecStatus: 
        """
        Returns copy of exec status of algorithm

        Returns copy of exec status of algorithm
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Perform(self,theShape : OCP.TopoDS.TopoDS_Shape,theParameters : IMeshTools_Parameters) -> OCP.IMeshData.IMeshData_Model: 
        """
        Exceptions protected method to create discrete model for the given shape. Returns nullptr in case of failure.
        """
    @staticmethod
    @overload
    def PrepareReport_s(theError : OCP.TColStd.TColStd_HPackedMapOfInteger,theMaxCount : int) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        Prepares a string containing a list of integers contained in theError map, but not more than theMaxCount

        Prepares a string containing a list of names contained in theReportSeq sequence, but not more than theMaxCount
        """
    @staticmethod
    @overload
    def PrepareReport_s(theReportSeq : OCP.TColStd.TColStd_SequenceOfHExtendedString,theMaxCount : int) -> OCP.TCollection.TCollection_ExtendedString: ...
    def SendMessages(self,theTraceLevel : OCP.Message.Message_Gravity=Message_Gravity.Message_Warning,theMaxCount : int=20) -> None: 
        """
        Convenient variant of SendStatusMessages() with theFilter having defined all WARN, ALARM, and FAIL (but not DONE) status flags
        """
    def SendStatusMessages(self,theFilter : OCP.Message.Message_ExecStatus,theTraceLevel : OCP.Message.Message_Gravity=Message_Gravity.Message_Warning,theMaxCount : int=20) -> None: 
        """
        Print messages for all status flags that have been set during algorithm execution, excluding statuses that are NOT set in theFilter.
        """
    def SetMessenger(self,theMsgr : OCP.Message.Message_Messenger) -> None: 
        """
        Sets messenger to algorithm
        """
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status) -> None: 
        """
        Sets status with no parameter

        Sets status with integer parameter

        Sets status with string parameter. If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with string parameter If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with string parameter If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with string parameter If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with string parameter If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with preformatted message. This message will be used directly to report the status; automatic generation of status messages will be disabled for it.

        Sets status with string parameter. If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with string parameter If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with string parameter If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag

        Sets status with string parameter If noRepetitions is True, the parameter will be added only if it has not been yet recorded for the same status flag
        """
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theInt : int) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : str,noRepetitions : bool=True) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : OCP.TCollection.TCollection_AsciiString,noRepetitions : bool=True) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : OCP.TCollection.TCollection_HAsciiString,noRepetitions : bool=True) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : OCP.TCollection.TCollection_ExtendedString,noRepetitions : bool=True) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : OCP.TCollection.TCollection_HExtendedString,noRepetitions : bool=True) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theMsg : OCP.Message.Message_Msg) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : str,noRepetitions : bool) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : OCP.TCollection.TCollection_AsciiString,noRepetitions : bool) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : OCP.TCollection.TCollection_HAsciiString,noRepetitions : bool) -> None: ...
    @overload
    def SetStatus(self,theStat : OCP.Message.Message_Status,theStr : OCP.TCollection.TCollection_ExtendedString,noRepetitions : bool) -> None: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class IMeshTools_Parameters():
    """
    Structure storing meshing parameters
    """
    @staticmethod
    def RelMinSize_s() -> float: 
        """
        Returns factor used to compute default value of MinSize (minimum mesh edge length) from deflection
        """
    def __init__(self) -> None: ...
    @property
    def AdjustMinSize(self) -> bool:
        """
        :type: bool
        """
    @AdjustMinSize.setter
    def AdjustMinSize(self, arg0: bool) -> None:
        pass
    @property
    def AllowQualityDecrease(self) -> bool:
        """
        :type: bool
        """
    @AllowQualityDecrease.setter
    def AllowQualityDecrease(self, arg0: bool) -> None:
        pass
    @property
    def Angle(self) -> float:
        """
        :type: float
        """
    @Angle.setter
    def Angle(self, arg0: float) -> None:
        pass
    @property
    def AngleInterior(self) -> float:
        """
        :type: float
        """
    @AngleInterior.setter
    def AngleInterior(self, arg0: float) -> None:
        pass
    @property
    def CleanModel(self) -> bool:
        """
        :type: bool
        """
    @CleanModel.setter
    def CleanModel(self, arg0: bool) -> None:
        pass
    @property
    def ControlSurfaceDeflection(self) -> bool:
        """
        :type: bool
        """
    @ControlSurfaceDeflection.setter
    def ControlSurfaceDeflection(self, arg0: bool) -> None:
        pass
    @property
    def Deflection(self) -> float:
        """
        :type: float
        """
    @Deflection.setter
    def Deflection(self, arg0: float) -> None:
        pass
    @property
    def DeflectionInterior(self) -> float:
        """
        :type: float
        """
    @DeflectionInterior.setter
    def DeflectionInterior(self, arg0: float) -> None:
        pass
    @property
    def EnableControlSurfaceDeflectionAllSurfaces(self) -> bool:
        """
        :type: bool
        """
    @EnableControlSurfaceDeflectionAllSurfaces.setter
    def EnableControlSurfaceDeflectionAllSurfaces(self, arg0: bool) -> None:
        pass
    @property
    def ForceFaceDeflection(self) -> bool:
        """
        :type: bool
        """
    @ForceFaceDeflection.setter
    def ForceFaceDeflection(self, arg0: bool) -> None:
        pass
    @property
    def InParallel(self) -> bool:
        """
        :type: bool
        """
    @InParallel.setter
    def InParallel(self, arg0: bool) -> None:
        pass
    @property
    def InternalVerticesMode(self) -> bool:
        """
        :type: bool
        """
    @InternalVerticesMode.setter
    def InternalVerticesMode(self, arg0: bool) -> None:
        pass
    @property
    def MeshAlgo(self) -> IMeshTools_MeshAlgoType:
        """
        :type: IMeshTools_MeshAlgoType
        """
    @MeshAlgo.setter
    def MeshAlgo(self, arg0: IMeshTools_MeshAlgoType) -> None:
        pass
    @property
    def MinSize(self) -> float:
        """
        :type: float
        """
    @MinSize.setter
    def MinSize(self, arg0: float) -> None:
        pass
    @property
    def Relative(self) -> bool:
        """
        :type: bool
        """
    @Relative.setter
    def Relative(self, arg0: bool) -> None:
        pass
    pass
class IMeshTools_ShapeExplorer(OCP.IMeshData.IMeshData_Shape, OCP.Standard.Standard_Transient):
    """
    Explores TopoDS_Shape for parts to be meshed - faces and free edges.
    """
    def Accept(self,theVisitor : IMeshTools_ShapeVisitor) -> None: 
        """
        Starts exploring of a shape.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetShape(self) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns shape assigned to discrete shape.
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def SetShape(self,theShape : OCP.TopoDS.TopoDS_Shape) -> None: 
        """
        Assigns shape to discrete shape.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self,theShape : OCP.TopoDS.TopoDS_Shape) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class IMeshTools_ShapeVisitor(OCP.Standard.Standard_Transient):
    """
    Interface class for shape visitor.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @overload
    def Visit(self,theFace : OCP.TopoDS.TopoDS_Face) -> None: 
        """
        Handles TopoDS_Face object.

        Handles TopoDS_Edge object.
        """
    @overload
    def Visit(self,theEdge : OCP.TopoDS.TopoDS_Edge) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
IMeshTools_MeshAlgoType_DEFAULT: OCP.IMeshTools.IMeshTools_MeshAlgoType # value = <IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_DEFAULT: -1>
IMeshTools_MeshAlgoType_Delabella: OCP.IMeshTools.IMeshTools_MeshAlgoType # value = <IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_Delabella: 1>
IMeshTools_MeshAlgoType_Watson: OCP.IMeshTools.IMeshTools_MeshAlgoType # value = <IMeshTools_MeshAlgoType.IMeshTools_MeshAlgoType_Watson: 0>



import OCP.XmlTObjDrivers
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import io
import OCP.PCDM
import OCP.Storage
import OCP.XmlLDrivers
import OCP.CDM
import OCP.Message
import OCP.TDocStd
import OCP.Standard
import OCP.XmlObjMgt
import OCP.TDF
import OCP.XmlMDF
__all__  = [
"XmlTObjDrivers",
"XmlTObjDrivers_DocumentRetrievalDriver",
"XmlTObjDrivers_DocumentStorageDriver",
"XmlTObjDrivers_IntSparseArrayDriver",
"XmlTObjDrivers_ModelDriver",
"XmlTObjDrivers_ObjectDriver",
"XmlTObjDrivers_ReferenceDriver",
"XmlTObjDrivers_XYZDriver"
]
class XmlTObjDrivers():
    """
    Class for registering storage/retrieval drivers for TObj XML persistence
    """
    @staticmethod
    def AddDrivers_s(aDriverTable : OCP.XmlMDF.XmlMDF_ADriverTable,anMsgDrv : OCP.Message.Message_Messenger) -> None: ...
    @staticmethod
    def DefineFormat_s(theApp : OCP.TDocStd.TDocStd_Application) -> None: 
        """
        Defines format "TObjXml" and registers its read and write drivers in the specified application
        """
    @staticmethod
    def Factory_s(aGUID : OCP.Standard.Standard_GUID) -> OCP.Standard.Standard_Transient: 
        """
        Returns a driver corresponding to <aGUID>. Used for plugin.
        """
    def __init__(self) -> None: ...
    pass
class XmlTObjDrivers_DocumentRetrievalDriver(OCP.XmlLDrivers.XmlLDrivers_DocumentRetrievalDriver, OCP.PCDM.PCDM_RetrievalDriver, OCP.PCDM.PCDM_Reader, OCP.Standard.Standard_Transient):
    def AttributeDrivers(self,theMsgDriver : OCP.Message.Message_Messenger) -> OCP.XmlMDF.XmlMDF_ADriverTable: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    @staticmethod
    def DocumentVersion_s(theFileName : OCP.TCollection.TCollection_ExtendedString,theMsgDriver : OCP.Message.Message_Messenger) -> int: ...
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetFormat(self) -> OCP.TCollection.TCollection_ExtendedString: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetStatus(self) -> OCP.PCDM.PCDM_ReaderStatus: ...
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    @overload
    def Read(self,theFileName : OCP.TCollection.TCollection_ExtendedString,theNewDocument : OCP.CDM.CDM_Document,theApplication : OCP.CDM.CDM_Application,theFilter : OCP.PCDM.PCDM_ReaderFilter=None,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: ...
    @overload
    def Read(self,theIStream : io.BytesIO,theStorageData : OCP.Storage.Storage_Data,theDoc : OCP.CDM.CDM_Document,theApplication : OCP.CDM.CDM_Application,theFilter : OCP.PCDM.PCDM_ReaderFilter=None,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: ...
    @staticmethod
    def ReferenceCounter_s(theFileName : OCP.TCollection.TCollection_ExtendedString,theMsgDriver : OCP.Message.Message_Messenger) -> int: ...
    def SetFormat(self,aformat : OCP.TCollection.TCollection_ExtendedString) -> None: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class XmlTObjDrivers_DocumentStorageDriver(OCP.XmlLDrivers.XmlLDrivers_DocumentStorageDriver, OCP.PCDM.PCDM_StorageDriver, OCP.PCDM.PCDM_Writer, OCP.Standard.Standard_Transient):
    def AttributeDrivers(self,theMsgDriver : OCP.Message.Message_Messenger) -> OCP.XmlMDF.XmlMDF_ADriverTable: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetFormat(self) -> OCP.TCollection.TCollection_ExtendedString: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetStoreStatus(self) -> OCP.PCDM.PCDM_StoreStatus: ...
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsError(self) -> bool: ...
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    @overload
    def Make(self,aDocument : OCP.CDM.CDM_Document) -> OCP.PCDM.PCDM_Document: 
        """
        raises NotImplemented.

        By default, puts in the Sequence the document returns by the previous Make method.
        """
    @overload
    def Make(self,aDocument : OCP.CDM.CDM_Document,Documents : OCP.PCDM.PCDM_SequenceOfDocument) -> None: ...
    def SetFormat(self,aformat : OCP.TCollection.TCollection_ExtendedString) -> None: ...
    def SetIsError(self,theIsError : bool) -> None: ...
    def SetStoreStatus(self,theStoreStatus : OCP.PCDM.PCDM_StoreStatus) -> None: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    @overload
    def Write(self,theDocument : OCP.CDM.CDM_Document,theFileName : OCP.TCollection.TCollection_ExtendedString,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: ...
    @overload
    def Write(self,theDocument : OCP.CDM.CDM_Document,theOStream : io.BytesIO,theRange : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> None: ...
    def __init__(self,theCopyright : OCP.TCollection.TCollection_ExtendedString) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class XmlTObjDrivers_IntSparseArrayDriver(OCP.XmlMDF.XmlMDF_ADriver, OCP.Standard.Standard_Transient):
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns the current message driver of this driver
        """
    def Namespace(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the namespace string
        """
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: ...
    @overload
    def Paste(self,theSource : OCP.XmlObjMgt.XmlObjMgt_Persistent,theTarget : OCP.TDF.TDF_Attribute,theRelocTable : OCP.XmlObjMgt.XmlObjMgt_RRelocationTable) -> bool: ...
    @overload
    def Paste(self,theSource : OCP.TDF.TDF_Attribute,theTarget : OCP.XmlObjMgt.XmlObjMgt_Persistent,theRelocTable : OCP.XmlObjMgt.XmlObjMgt_SRelocationTable) -> None: ...
    def SourceType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns the type of source object, inheriting from Attribute from TDF.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeName(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the full XML tag name (including NS prefix)
        """
    def VersionNumber(self) -> int: 
        """
        Returns the version number from which the driver is available.
        """
    def __init__(self,theMessageDriver : OCP.Message.Message_Messenger) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class XmlTObjDrivers_ModelDriver(OCP.XmlMDF.XmlMDF_ADriver, OCP.Standard.Standard_Transient):
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns the current message driver of this driver
        """
    def Namespace(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the namespace string
        """
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: ...
    @overload
    def Paste(self,Source : OCP.XmlObjMgt.XmlObjMgt_Persistent,Target : OCP.TDF.TDF_Attribute,RelocTable : OCP.XmlObjMgt.XmlObjMgt_RRelocationTable) -> bool: ...
    @overload
    def Paste(self,Source : OCP.TDF.TDF_Attribute,Target : OCP.XmlObjMgt.XmlObjMgt_Persistent,RelocTable : OCP.XmlObjMgt.XmlObjMgt_SRelocationTable) -> None: ...
    def SourceType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns the type of source object, inheriting from Attribute from TDF.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeName(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the full XML tag name (including NS prefix)
        """
    def VersionNumber(self) -> int: 
        """
        Returns the version number from which the driver is available.
        """
    def __init__(self,theMessageDriver : OCP.Message.Message_Messenger) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class XmlTObjDrivers_ObjectDriver(OCP.XmlMDF.XmlMDF_ADriver, OCP.Standard.Standard_Transient):
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns the current message driver of this driver
        """
    def Namespace(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the namespace string
        """
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: ...
    @overload
    def Paste(self,Source : OCP.XmlObjMgt.XmlObjMgt_Persistent,Target : OCP.TDF.TDF_Attribute,RelocTable : OCP.XmlObjMgt.XmlObjMgt_RRelocationTable) -> bool: ...
    @overload
    def Paste(self,Source : OCP.TDF.TDF_Attribute,Target : OCP.XmlObjMgt.XmlObjMgt_Persistent,RelocTable : OCP.XmlObjMgt.XmlObjMgt_SRelocationTable) -> None: ...
    def SourceType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns the type of source object, inheriting from Attribute from TDF.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeName(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the full XML tag name (including NS prefix)
        """
    def VersionNumber(self) -> int: 
        """
        Returns the version number from which the driver is available.
        """
    def __init__(self,theMessageDriver : OCP.Message.Message_Messenger) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class XmlTObjDrivers_ReferenceDriver(OCP.XmlMDF.XmlMDF_ADriver, OCP.Standard.Standard_Transient):
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns the current message driver of this driver
        """
    def Namespace(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the namespace string
        """
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: ...
    @overload
    def Paste(self,Source : OCP.XmlObjMgt.XmlObjMgt_Persistent,Target : OCP.TDF.TDF_Attribute,RelocTable : OCP.XmlObjMgt.XmlObjMgt_RRelocationTable) -> bool: ...
    @overload
    def Paste(self,Source : OCP.TDF.TDF_Attribute,Target : OCP.XmlObjMgt.XmlObjMgt_Persistent,RelocTable : OCP.XmlObjMgt.XmlObjMgt_SRelocationTable) -> None: ...
    def SourceType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns the type of source object, inheriting from Attribute from TDF.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeName(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the full XML tag name (including NS prefix)
        """
    def VersionNumber(self) -> int: 
        """
        Returns the version number from which the driver is available.
        """
    def __init__(self,theMessageDriver : OCP.Message.Message_Messenger) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class XmlTObjDrivers_XYZDriver(OCP.XmlMDF.XmlMDF_ADriver, OCP.Standard.Standard_Transient):
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns the current message driver of this driver
        """
    def Namespace(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the namespace string
        """
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: ...
    @overload
    def Paste(self,Source : OCP.XmlObjMgt.XmlObjMgt_Persistent,Target : OCP.TDF.TDF_Attribute,RelocTable : OCP.XmlObjMgt.XmlObjMgt_RRelocationTable) -> bool: ...
    @overload
    def Paste(self,Source : OCP.TDF.TDF_Attribute,Target : OCP.XmlObjMgt.XmlObjMgt_Persistent,RelocTable : OCP.XmlObjMgt.XmlObjMgt_SRelocationTable) -> None: ...
    def SourceType(self) -> OCP.Standard.Standard_Type: 
        """
        Returns the type of source object, inheriting from Attribute from TDF.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def TypeName(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the full XML tag name (including NS prefix)
        """
    def VersionNumber(self) -> int: 
        """
        Returns the version number from which the driver is available.
        """
    def __init__(self,theMessageDriver : OCP.Message.Message_Messenger) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
